# SV Geometry

A collection of functions for bidimensional and tridimensional arithmetic geometry.

## Installing

    pip install sv-geometry

## Relevant links:

* Official page on PyPI: https://pypi.org/project/sv-geometry/
* Issue tracker: https://github.com/ihavenonickname/sv-geometry/issues
